==> yndenz-notify-yndenz-1.0.5-b19520.zip: changelog.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [Unreleased]

### [1.0.5] - 2019-11-05
### Changed
- Prevent bots from sending console errors

### [1.0.4] - 2019-11-05
### Fixed
- Check if request URI exists before adding it to the message

### [1.0.3] - 2019-11-05
### Fixed
- Request uri in ALL PHP error notifications

### [1.0.2] - 2019-11-05
### Added
- Request uri in PHP error notifications (for better debugging)

### [1.0.1] - 2019-11-04
### Fixed
- Undefined index file

### [1.0.0] - 2019-10-24
### Changed
- Also mention the browser in console errors

### Fixed
- One-line errors displayed as 0

## [0.0.1] - 2019-10-09
### Added
- Notify yndenz about console errors
- Notify yndenz about PHP errors

[Unreleased]: https://gitlab.yndenz.com/yndenz-modules/optimize-images/compare/1.0.5...HEAD
[1.0.5]: https://gitlab.yndenz.com/yndenz-modules/optimize-images/compare/1.0.4...1.0.5
[1.0.4]: https://gitlab.yndenz.com/yndenz-modules/optimize-images/compare/1.0.3...1.0.4
[1.0.3]: https://gitlab.yndenz.com/yndenz-modules/optimize-images/compare/1.0.2...1.0.3
[1.0.2]: https://gitlab.yndenz.com/yndenz-modules/optimize-images/compare/1.0.1...1.0.2
[1.0.1]: https://gitlab.yndenz.com/yndenz-modules/optimize-images/compare/1.0.0...1.0.1
[1.0.0]: https://gitlab.yndenz.com/yndenz-modules/optimize-images/compare/0.0.1...1.0.0
[0.0.1]: https://gitlab.yndenz.com/yndenz-modules/optimize-images/compare/0.0.0...0.0.1

==> yndenz-notify-yndenz-1.0.8-a45899.zip: changelog.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [Unreleased]

### [1.0.8] - 2019-11-15
### Fixed
- Undefined index HTTP_REFERER in console errors

### [1.0.7] - 2019-11-06
### Changed
- Prevent console errors from BaiduSpider

### [1.0.6] - 2019-11-05
### Changed
- Ignore suppressed errors

### [1.0.5] - 2019-11-05
### Changed
- Prevent bots from sending console errors

### [1.0.4] - 2019-11-05
### Fixed
- Check if request URI exists before adding it to the message

### [1.0.3] - 2019-11-05
### Fixed
- Request uri in ALL PHP error notifications

### [1.0.2] - 2019-11-05
### Added
- Request uri in PHP error notifications (for better debugging)

### [1.0.1] - 2019-11-04
### Fixed
- Undefined index file

### [1.0.0] - 2019-10-24
### Changed
- Also mention the browser in console errors

### Fixed
- One-line errors displayed as 0

## [0.0.1] - 2019-10-09
### Added
- Notify yndenz about console errors
- Notify yndenz about PHP errors

[Unreleased]: https://gitlab.yndenz.com/yndenz-modules/optimize-images/compare/1.0.8...HEAD
[1.0.8]: https://gitlab.yndenz.com/yndenz-modules/optimize-images/compare/1.0.7...1.0.8
[1.0.7]: https://gitlab.yndenz.com/yndenz-modules/optimize-images/compare/1.0.6...1.0.7
[1.0.6]: https://gitlab.yndenz.com/yndenz-modules/optimize-images/compare/1.0.5...1.0.6
[1.0.5]: https://gitlab.yndenz.com/yndenz-modules/optimize-images/compare/1.0.4...1.0.5
[1.0.4]: https://gitlab.yndenz.com/yndenz-modules/optimize-images/compare/1.0.3...1.0.4
[1.0.3]: https://gitlab.yndenz.com/yndenz-modules/optimize-images/compare/1.0.2...1.0.3
[1.0.2]: https://gitlab.yndenz.com/yndenz-modules/optimize-images/compare/1.0.1...1.0.2
[1.0.1]: https://gitlab.yndenz.com/yndenz-modules/optimize-images/compare/1.0.0...1.0.1
[1.0.0]: https://gitlab.yndenz.com/yndenz-modules/optimize-images/compare/0.0.1...1.0.0
[0.0.1]: https://gitlab.yndenz.com/yndenz-modules/optimize-images/compare/0.0.0...0.0.1
